CredoDeprecate.Checks.DeprecateSigil (credo_deprecate v0.1.10)

Basics

This check is disabled by default.

Learn how to enable it via .credo.exs.

This check has a base priority of high and works with any version of Elixir.

Explanation

Prevents new usage of deprecated sigils while allowing existing usage via an allow_list.

Check-Specific Parameters

Use the following parameters to configure this check:

:sigil

An atom specifying the deprecated sigil (e.g., :sigil_F for ~F from Surface).

This parameter defaults to nil.

:allow_list

List of modules that are allowed to continue using the deprecated sigil.

This parameter defaults to [].

:message

Custom error message to display when the deprecated sigil is used.

This parameter defaults to nil.

General Parameters

Like with all checks, general params can be applied.

Parameters can be configured via the .credo.exs config file.